==> apeman-task-setupdb-2.0.3.tgz: package/lib/define.js <==
/**
 * apeman task to setup database.
 * @memberof module:apeman-task-setupdb/lib
 * @function define
 * @param {Apemandb|string} db - Apeman database instance or it's module path.
 * @param {object} [options] - Optional settings.
 * @returns {function} - Defined task function.
 */

"use strict";

const argx = require('argx'),
    assert = require('assert'),
    path = require('path'),
    async = require('async'),
    findout = require('findout'),
    objnest = require('objnest');

const setupMysql = require('./setup/setup_mysql'),
    setupSqlite = require('./setup/setup_sqlite'),
    setupPostgres = require('./setup/setup_postgres');

/** @lends define */
function define(db, options) {
    let args = argx(arguments);
    options = objnest.expand(args.pop('object') || {});

    /**
     * Defined task.
     * @function task
     * @param {object} context - Apeman task context.
     * @param {function} callback - Callback when done.
     */
    function task(context, callback) {

        if (typeof(db) === 'string') {
            db = findout(db);
        }

        assert.ok(db, "db is required.");

        let env = db.env;
        assert.ok(env, "db.env is required.");

        env = _upperKeys(env || {});

        let logger = context.logger,
            verbose = context.verbose;

        async.series([
            (callback) => {
                logger.debug(`Setup database...`);
                var NODE_ENV = process.env.NODE_ENV;
                if (NODE_ENV) {
                    logger.trace(`\tNODE_ENV=${NODE_ENV}`);
                }
                if (verbose) {
                    logger.trace(env);
                }
                callback();
            },
            (callback) => {
                let dialect = env.DIALECT;
                switch (dialect) {
                    case 'mysql':
                        setupMysql(env, callback);
                        break;
                    case 'postgres':
                        setupPostgres(env, callback);
                        break;
                    case 'sqlite':
                        setupSqlite(env, callback);
                        break;
                    default:
                        callback(new Error('Unknown dialect: ' + dialect));
                }
            },
            (callback) => {
                logger.debug(`...Done!`);
                callback(null);
            }
        ], (err) => {
            process.nextTick(()=> {
                callback(err);
            });
        });
    }

    // Description of this task.
    task.$desc = "Setup database.";
    return task;
}

function _upperKeys(obj) {
    let result = {};
    Object.keys(obj).forEach((key) => {
        result[key.toUpperCase()] = obj[key];
    });
    return result;
}

module.exports = define;

==> apeman-task-setupdb-2.0.8.tgz: package/lib/define.js <==
/**
 * apeman task to setup database.
 * @memberof module:apeman-task-setupdb/lib
 * @function define
 * @param {Apemandb|string} db - Apeman database instance or it's module path.
 * @param {object} [options] - Optional settings.
 * @returns {function} - Defined task function.
 */

"use strict";

const argx = require('argx'),
    assert = require('assert'),
    path = require('path'),
    async = require('async'),
    findout = require('findout'),
    objnest = require('objnest');

const setupMysql = require('./setup/setup_mysql'),
    setupSqlite = require('./setup/setup_sqlite'),
    setupPostgres = require('./setup/setup_postgres');

/** @lends define */
function define(db, options) {
    let args = argx(arguments);
    options = objnest.expand(args.pop('object') || {});

    /**
     * Defined task.
     * @function task
     * @param {object} context - Apeman task context.
     * @param {function} callback - Callback when done.
     */
    function task(context, callback) {

        if (typeof(db) === 'string') {
            db = findout(db);
        }

        assert.ok(db, "db is required.");

        let env = db.env;
        assert.ok(env, "db.env is required.");

        env = _upperKeys(env || {});

        let logger = context.logger,
            verbose = context.verbose;

        let dialect = env.DIALECT;
        async.series([
            (callback) => {
                logger.debug(`Setup database...`);
                let NODE_ENV = process.env.NODE_ENV;
                if (NODE_ENV) {
                    logger.debug(`NODE_ENV: ${NODE_ENV}`);
                }
                logger.debug(`dialect: ${dialect}`);
                if (verbose) {
                    logger.trace(env);
                }
                callback();
            },
            (callback) => {

                switch (dialect) {
                    case 'mysql':
                        setupMysql(env, callback);
                        break;
                    case 'postgres':
                        setupPostgres(env, callback);
                        break;
                    case 'sqlite':
                        setupSqlite(env, callback);
                        break;
                    default:
                        callback(new Error('Unknown dialect: ' + dialect));
                }
            },
            (callback) => {
                logger.debug(`...Done!`);
                callback(null);
            }
        ], (err) => {
            process.nextTick(()=> {
                callback(err);
            });
        });
    }

    // Description of this task.
    task.$desc = "Setup database.";
    return task;
}

function _upperKeys(obj) {
    let result = {};
    Object.keys(obj).forEach((key) => {
        result[key.toUpperCase()] = obj[key];
    });
    return result;
}

module.exports = define;
